@@ -57,11 +57,12 @@ class RundeckJobs(object):
         subprocess.run(command, cwd=cwd, check=check)
 
     def clone_rundeck_codebase(self, gitlab_deploy_token: str):
+        repository_directory = tempfile.mkdtemp()
         with tempfile.TemporaryDirectory() as tmpdir:
             self.run_command(["git", "clone", "--depth", "1",
                               f"https://oauth2:{gitlab_deploy_token}@gitlab.zadapps.info/infrastructure/rundeck/rundeck.git",
-                              tmpdir], cwd="/tmp")
-            return tmpdir
+                              repository_directory], cwd="/tmp")
+        return repository_directory
 
     def search_uptimerobot(
             self,
@@ -465,7 +466,7 @@ class RundeckJobs(object):
                               "default"], cwd=terraform_code_dir, check=True)
             self.run_command(["terraform", "workspace", "delete", f"{fqdn}.build"],
                              cwd=terraform_code_dir, check=True)
-        rmdir(terraform_code_dir)
+        rmdir(rundeck_codebase_dir)
 
     @retry(wait=wait_random(*wait_random_range), stop=stop_after_attempt(number_of_retries))
     def nextjs_deploy(
@@ -530,7 +531,7 @@ class RundeckJobs(object):
              backend_config_file_location], cwd=terraform_code_dir,
             check=True)
 
-        vars_file_location = f"{config_dir_location}/{fqdn}.auto.tfvars"
+        vars_file_location = f"/tmp/{fqdn}.auto.tfvars"
         vars_file_content = f"""fqdn = "{fqdn}"
             git_branch = "{git_branch}"
             project_name = "{project_name}"
@@ -566,4 +567,4 @@ class RundeckJobs(object):
                                            execution_mode=execution_mode, deployment_environment=deployment_environment,
                                            deployment_action=deployment_action)
 
-        rmdir(terraform_code_dir)
+        rmdir(rundeck_codebase_dir)
